/*************************************************************************
 *   iglvers - show some info from IRIS GL
 *   Copyright (C) 2018 jrra
 * 
 *   to build:
 *       cc -o iglvers iglvers.c -lgl
 ************************************************************************/

#include <stdio.h>
#include <string.h>

#include <gl/gl.h>

struct gfxhwdesctablenode {
	char *version;
	char *description;
	int end;
} hwtable[] = {
	/* This table associates the values returned from gversion()
	 * with a description of the graphics hardware.
	 * For more information, check the manpage of gversion. */
	{ "GL4D",	"B or G"				},
	{ "GL4DGT",	"GT"					},
	{ "GL4DGTX",	"GTX"					},
	{ "GL4DVGX",	"VGX"					},
	{ "GL4DVGXT",	"VGXT"					},
	{ "GL4DRE",	"RealityEngine"				},
	{ "GL4DPI",	"very early Personal Iris"		},
	{ "GL4DPI2",	"Personal Iris" 			},
	{ "GL4DPIT",	"Personal Iris with Turbo Graphics"	},
	{ "GL4DLG",	"Entry"					},
	{ "GL4DXG",	"XS, XS24, XZ, Elan, or Extreme"	},
	{ "GL4DNP",	"Indy"					},
	{ "GL4DSLD",	"Solid IMPACT"				},
	{ "GL4DIMP",	"High IMPACT or Maximum IMPACT"		},
	{ "GL4DINF",	"InfiniteReality"			},
	{ "GL4DIOO",	"VPro"					},
	{ "", "", 1 },	/* end-of-array sentinel */
};

void die( char *msg )
{
	fprintf( stderr, "%s\n", msg );
	exit(1);
}

char *getDescFromVersion(char *v)
{
	char version[13];
	char *dash;
	int i;
	
	strncpy(version, v, 12);
	dash = strchr(version, '-');
	if (dash)
		*dash = '\0';
	else
		return "unknown";
	
	i=0;
	while(!hwtable[i].end) {
		if( !strcmp( version, hwtable[i].version ) )
			return hwtable[i].description;
		++i;
	}
	return "unknown";
}

int main( int argc, char *argv[] ) {
	char version[13];
	printf("IrisGL implementation is %s.\n", getgdesc(GD_IS_NATIVE) ?
		"native" :
		"non-native, layered on OpenGL"
	);
	printf("multisampling %s.\n", getgdesc(GD_MULTISAMPLE) ?
		"available" :
		"not available"
	);
	printf("screen type is %s.\n", getgdesc(GD_SCRNTYPE)==GD_SCRNTYPE_WM ?
		"GD_SCRNTYPE_WM (has window manager)" :
		"GD_SCRNTYPE_NOWM (no window manager)"
	);
	printf("GD_WSYS is %s.\n", getgdesc(GD_WSYS)==GD_WSYS_4S ?
		"GD_WSYS_4S (windowing system currently running)" :
		"GD_WSYS_NONE (no window system currently running)"
	);
	gversion(version);
	printf("gversion is %s (%s).\n", version, getDescFromVersion(version));
	
	return 0;
}
